from RPi import GPIO


class HallSensor:
    def __init__(self, read_pin):
        """
        Initialise HallSensor module with digital pin
        :param read_pin: Integer representing a BCM pin
        """
        GPIO.setmode(GPIO.BCM)
        self.__read_pin = read_pin
        GPIO.setup(self.__read_pin, GPIO.IN)
        GPIO.add_event_detect(self.__read_pin, GPIO.FALLING, bouncetime=300)

    def set_callback(self, cb):
        """
        Add a callback funtion when 1 is detected on the pin
        :param cb: Callback function created by user
        :return: Callback is executed on action
        """
        GPIO.add_event_callback(self.__read_pin, cb)

    def remove_callback(self):
        """
        Remove the callback detection
        """
        GPIO.remove_event_detect(self.__read_pin)
