from RPi import GPIO
import time

DEVICE_DELAY_TIME = 1 / 4


class L298N:
    def __init__(self, in1, in2, in3, in4):
        """
        Initialise a H bridge with 2 dc motors connected
        :param in1 - in2 - in3 - in4: Pinnumbers representing the IN pins on the L298N module
        """
        GPIO.setmode(GPIO.BCM)
        self.__in1 = in1
        self.__in2 = in2
        self.__in3 = in3
        self.__in4 = in4
        self.__common_pins1 = [self.__in1, self.__in3]
        self.__common_pins2 = [self.__in2, self.__in4]
        self.__all_pins = self.__common_pins1 + self.__common_pins2

    # Private functions

    def __setup_forward(self):
        """
        Setup the pins to drive forward
        """
        for pin in self.__common_pins2:
            GPIO.setup(pin, GPIO.IN)
        for pin in self.__common_pins1:
            GPIO.setup(pin, GPIO.OUT)
            GPIO.output(pin, 0)

    def __setup_backward(self):
        """
        Setup the pins to drive backwards
        """
        for pin in self.__common_pins2:
            GPIO.setup(pin, GPIO.OUT)
            GPIO.output(pin, 0)
        for pin in self.__common_pins1:
            GPIO.setup(pin, GPIO.IN)

    # Public functions

    def rotate_forward(self):
        """
        Output 1 to the OUT pins so that the H brigde is active and rotates forward
        """
        time.sleep(DEVICE_DELAY_TIME)
        self.__setup_forward()
        for pin in self.__common_pins1:
            GPIO.output(pin, 1)

    def stop_rotating_forward(self):
        """
        Output 0 to the OUT pins so that the H Brigde stops
        """
        for pin in self.__common_pins1:
            GPIO.output(pin, 0)
        time.sleep(DEVICE_DELAY_TIME)

    def rotate_reverse(self):
        """
        Output 1 to the OUT pins so that the H brigde is active and rotates backwards
        :return:
        """
        time.sleep(DEVICE_DELAY_TIME)
        self.__setup_backward()
        for pin in self.__common_pins2:
            GPIO.output(pin, 1)

    def stop_rotating_reverse(self):
        """
        Output 0 to the OUT pins so that the H Brigde stops
        """
        for pin in self.__common_pins2:
            GPIO.output(pin, 0)
        time.sleep(DEVICE_DELAY_TIME)

    def rotate_right_side(self):
        """
        Activate only 1 side of the H Bridge engines
        """
        time.sleep(DEVICE_DELAY_TIME)
        self.__setup_forward()
        pin_vals = [1, 0]
        for pin in enumerate(self.__common_pins1):
            GPIO.output(pin[1], pin_vals[pin[0]])

    def rotate_left_side(self):
        """
        Activate only 1 side of the H Bridge engines
        """
        time.sleep(DEVICE_DELAY_TIME)
        self.__setup_forward()
        pin_vals = [0, 1]
        for pin in enumerate(self.__common_pins1):
            GPIO.output(pin[1], pin_vals[pin[0]])

    # def __del__(self):
    #     """
    #     Clean up the mess
    #     """
    #     GPIO.cleanup()
