import serial


class Arduino:
    def __init__(self, port, baudrate=9600):
        self.__port = port
        self.__arduino = serial.Serial(self.__port, baudrate=baudrate)

    def __read_arduino(self):
        """
        Get byte data from Arduino over USB
        :return: A byte value
        """
        return self.__arduino.readline()

    def __read_as_string(self):
        """
        Convert bytes received from Arduino to Str
        :return: A string
        """
        data = self.__read_arduino()
        return str(data.decode("utf-8")).replace("\n", "")

    def get_data_array(self):
        """
        Convert the string of data to an array
        :return: An array of integer values returned by the sensors
        """
        d = self.__read_as_string()
        ar = d.split(",")
        for i in enumerate(ar):
            try:
                ar[i[0]] = int(i[1])
            except:
                ar[i[0]] = 120
        return ar

    def __del__(self):
        """
        Clean up the mess
        """
        self.__arduino.close()
